@@ -20,6 +20,7 @@ require "chef-config/workstation_config_loader"
 require "ohai"
 require "ohai/log"
 require "mixlib/cli"
+require "benchmark"
 
 class Ohai::Application
   include Mixlib::CLI
@@ -74,8 +75,11 @@ class Ohai::Application
   end
 
   def run
-    configure_ohai
-    run_application
+    elapsed = Benchmark.measure do
+      configure_ohai
+      run_application
+    end
+    Ohai::Log.debug("Ohai took #{elapsed.total} total seconds to run.")
   end
 
   def configure_ohai
@@ -83,9 +87,12 @@ class Ohai::Application
     @attributes = nil if @attributes.empty?
 
     load_workstation_config
+
+    Ohai::Log.init(Ohai.config[:log_location])
   end
 
   def run_application
+    config[:invoked_from_cli] = true
     ohai = Ohai::System.new(config)
     ohai.all_plugins(@attributes)
 
