@@ -65,6 +65,9 @@ module Ohai
         37 =>  "memory_channel",
         38 =>  "ipmi_device",
         39 =>  "power_supply",
+        40 =>  "additional_information",
+        41 =>  "onboard_devices_extended_information",
+        42 =>  "management_controller_host_interfaces",
         126 => "disabled_entries",
         127 => "end_of_table_marker",
       }
@@ -75,20 +78,18 @@ module Ohai
 
       # look up DMI ID
       def id_lookup(id)
-        begin
-          id = id.to_i
-          if (id >= 128) && (id <= 255)
-            id = "oem_data_#{id}"
-          elsif DMI::ID_TO_DESCRIPTION.has_key?(id)
-            id = DMI::ID_TO_DESCRIPTION[id]
-          else
-            Ohai::Log.debug("unrecognized header id; falling back to 'unknown'")
-            id = "unknown"
-          end
-        rescue
-          Ohai::Log.debug("failed to look up id #{id}, returning unchanged")
-          id
+        id = id.to_i
+        if (id >= 128) && (id <= 255)
+          id = "oem_data_#{id}"
+        elsif DMI::ID_TO_DESCRIPTION.has_key?(id)
+          id = DMI::ID_TO_DESCRIPTION[id]
+        else
+          Ohai::Log.debug("unrecognized header id; falling back to 'unknown'")
+          id = "unknown"
         end
+      rescue
+        Ohai::Log.debug("failed to look up id #{id}, returning unchanged")
+        id
       end
 
       # create simplified convenience access keys for each record type
@@ -115,7 +116,7 @@ module Ohai
             end
           end
           in_common.each do |field, value|
-            next if value == nil
+            next if value.nil?
             dmi[type][field] = value.strip
           end
         end
