@@ -85,10 +85,12 @@ module Ohai
       include Ohai::Util::FileHelper
 
       attr_reader :data
+      attr_reader :failed
 
       def initialize(data)
         @data = data
         @has_run = false
+        @failed = false
       end
 
       def run
@@ -154,8 +156,19 @@ module Ohai
         end
       end
 
-      def set_attribute(name, *values)
-        @data[name] = Array18(*values)
+      def set_attribute(name, *attrs, value)
+        # Initialize the path in the @data Mash with new Mashes, if needed.
+        # Will raise a TypeError if we hit a subattribute that is not a
+        # Hash, Mash, or Array.
+        keys = [name] + attrs
+        attribute = keys[0..-2].inject(@data) do |attrs, key|
+          attrs[key] ||= Mash.new
+          attrs[key]
+        end
+
+        # Set the subattribute to the value.
+        attr_name = attrs.empty? ? name : attrs[-1]
+        attribute[attr_name] = value
         @data[name]
       end
 
@@ -169,14 +182,14 @@ module Ohai
 
       # emulates the old plugin loading behavior
       def safe_run
-        begin
-          self.run
-        rescue Ohai::Exceptions::Error => e
-          raise e
-        rescue => e
-          Ohai::Log.debug("Plugin #{self.name} threw #{e.inspect}")
-          e.backtrace.each { |line| Ohai::Log.debug( line ) }
-        end
+        run
+      rescue Ohai::Exceptions::Error => e
+        @failed = true
+        raise e
+      rescue => e
+        @failed = true
+        Ohai::Log.debug("Plugin #{name} threw #{e.inspect}")
+        e.backtrace.each { |line| Ohai::Log.debug( line ) }
       end
 
       def method_missing(name, *args)
@@ -198,12 +211,6 @@ module Ohai
         # NoMethodError occurs when trying to access a key on nil
         nil
       end
-
-      def Array18(*args)
-        return nil if args.empty?
-        return args.first if args.length == 1
-        return *args
-      end
     end
   end
 end
