@@ -42,8 +42,10 @@ module ::Ohai::Mixin::DmiDecode
         return "kvm"
       when /Product.*: BHYVE/
         return "bhyve"
+      when /Manufacturer: Veertu/
+        return "veertu"
       end
     end
-    return nil
+    nil
   end
 end
