@@ -2,7 +2,7 @@
 # Author:: Tim Dysinger (<tim@dysinger.net>)
 # Author:: Benjamin Black (<bb@chef.io>)
 # Author:: Christopher Brown (<cb@chef.io>)
-# Copyright:: Copyright (c) 2009-2016 Chef Software, Inc.
+# Copyright:: 2009-2017 Chef Software, Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -18,7 +18,6 @@
 # limitations under the License.
 
 require "net/http"
-require "socket"
 
 module Ohai
   module Mixin
@@ -43,63 +42,41 @@ module Ohai
       EC2_METADATA_ADDR = "169.254.169.254" unless defined?(EC2_METADATA_ADDR)
       EC2_SUPPORTED_VERSIONS = %w{ 1.0 2007-01-19 2007-03-01 2007-08-29 2007-10-10 2007-12-15
                                    2008-02-01 2008-09-01 2009-04-04 2011-01-01 2011-05-01 2012-01-12
-                                   2014-11-05 2014-02-25 }
-
+                                   2014-02-25 2014-11-05 2015-10-20 2016-04-19 2016-06-30 2016-09-02 }
       EC2_ARRAY_VALUES = %w{security-groups}
       EC2_ARRAY_DIR    = %w{network/interfaces/macs}
       EC2_JSON_DIR     = %w{iam}
 
-      def can_metadata_connect?(addr, port, timeout = 2)
-        t = Socket.new(Socket::Constants::AF_INET, Socket::Constants::SOCK_STREAM, 0)
-        saddr = Socket.pack_sockaddr_in(port, addr)
-        connected = false
-
-        begin
-          t.connect_nonblock(saddr)
-        rescue Errno::EINPROGRESS
-          r, w, e = IO.select(nil, [t], nil, timeout)
-          if !w.nil?
-            connected = true
-          else
-            begin
-              t.connect_nonblock(saddr)
-            rescue Errno::EISCONN
-              t.close
-              connected = true
-            rescue SystemCallError
-            end
-          end
-        rescue SystemCallError
-        end
-        Ohai::Log.debug("ec2 metadata mixin: can_metadata_connect? == #{connected}")
-        connected
-      end
-
       def best_api_version
-        response = http_client.get("/")
-        if response.code == "404"
-          Ohai::Log.debug("ec2 metadata mixin: Received HTTP 404 from metadata server while determining API version, assuming 'latest'")
-          return "latest"
-        elsif response.code != "200"
-          raise "Unable to determine EC2 metadata version (returned #{response.code} response)"
+        @api_version ||= begin
+          Ohai::Log.debug("Mixin EC2: Fetching http://#{EC2_METADATA_ADDR}/ to determine the latest supported metadata release")
+          response = http_client.get("/")
+          if response.code == "404"
+            Ohai::Log.debug("Mixin EC2: Received HTTP 404 from metadata server while determining API version, assuming 'latest'")
+            return "latest"
+          elsif response.code != "200"
+            raise "Mixin EC2: Unable to determine EC2 metadata version (returned #{response.code} response)"
+          end
+          # Note: Sorting the list of versions may have unintended consequences in
+          # non-EC2 environments. It appears to be safe in EC2 as of 2013-04-12.
+          versions = response.body.split("\n").sort
+          until versions.empty? || EC2_SUPPORTED_VERSIONS.include?(versions.last)
+            pv = versions.pop
+            Ohai::Log.debug("Mixin EC2: EC2 lists metadata version: #{pv} not yet supported by Ohai") unless pv == "latest"
+          end
+          Ohai::Log.debug("Mixin EC2: Latest supported EC2 metadata version: #{versions.last}")
+          if versions.empty?
+            raise "Mixin EC2: Unable to determine EC2 metadata version (no supported entries found)"
+          end
+          versions.last
         end
-        # Note: Sorting the list of versions may have unintended consequences in
-        # non-EC2 environments. It appears to be safe in EC2 as of 2013-04-12.
-        versions = response.body.split("\n")
-        versions = response.body.split("\n").sort
-        until versions.empty? || EC2_SUPPORTED_VERSIONS.include?(versions.last)
-          pv = versions.pop
-          Ohai::Log.debug("ec2 metadata mixin: EC2 shows unsupported metadata version: #{pv}") unless pv == "latest"
-        end
-        Ohai::Log.debug("ec2 metadata mixin: EC2 metadata version: #{versions.last}")
-        if versions.empty?
-          raise "Unable to determine EC2 metadata version (no supported entries found)"
-        end
-        versions.last
       end
 
       def http_client
-        Net::HTTP.start(EC2_METADATA_ADDR).tap { |h| h.read_timeout = 30 }
+        @conn ||= Net::HTTP.start(EC2_METADATA_ADDR).tap do |h|
+          h.read_timeout = 10
+          h.keep_alive_timeout = 10
+        end
       end
 
       # Get metadata for a given path and API version
@@ -111,44 +88,42 @@ module Ohai
       #   `nil` and continue the run instead of failing it.
       def metadata_get(id, api_version)
         path = "/#{api_version}/meta-data/#{id}"
+        Ohai::Log.debug("Mixin EC2: Fetching http://#{EC2_METADATA_ADDR}#{path}")
         response = http_client.get(path)
         case response.code
         when "200"
           response.body
         when "404"
-          Ohai::Log.debug("ec2 metadata mixin: Encountered 404 response retreiving EC2 metadata path: #{path} ; continuing.")
+          Ohai::Log.debug("Mixin EC2: Encountered 404 response retrieving EC2 metadata path: #{path} ; continuing.")
           nil
         else
-          raise "Encountered error retrieving EC2 metadata (#{path} returned #{response.code} response)"
+          raise "Mixin EC2: Encountered error retrieving EC2 metadata (#{path} returned #{response.code} response)"
         end
       end
 
       def fetch_metadata(id = "", api_version = nil)
-        api_version ||= best_api_version
-        return {} if api_version.nil?
-
         metadata = {}
-        retrieved_metadata = metadata_get(id, api_version)
+        retrieved_metadata = metadata_get(id, best_api_version)
         if retrieved_metadata
           retrieved_metadata.split("\n").each do |o|
             key = expand_path("#{id}#{o}")
             if key[-1..-1] != "/"
               metadata[metadata_key(key)] =
                 if EC2_ARRAY_VALUES.include? key
-                  retr_meta = metadata_get(key, api_version)
+                  retr_meta = metadata_get(key, best_api_version)
                   retr_meta ? retr_meta.split("\n") : retr_meta
                 else
-                  metadata_get(key, api_version)
+                  metadata_get(key, best_api_version)
                 end
             elsif (not key.eql?(id)) && (not key.eql?("/"))
               name = key[0..-2]
               sym = metadata_key(name)
               if EC2_ARRAY_DIR.include?(name)
-                metadata[sym] = fetch_dir_metadata(key, api_version)
+                metadata[sym] = fetch_dir_metadata(key, best_api_version)
               elsif EC2_JSON_DIR.include?(name)
-                metadata[sym] = fetch_json_dir_metadata(key, api_version)
+                metadata[sym] = fetch_json_dir_metadata(key, best_api_version)
               else
-                fetch_metadata(key, api_version).each { |k, v| metadata[k] = v }
+                fetch_metadata(key, best_api_version).each { |k, v| metadata[k] = v }
               end
             end
           end
@@ -194,12 +169,23 @@ module Ohai
       end
 
       def fetch_userdata
-        api_version = best_api_version
-        return nil if api_version.nil?
-        response = http_client.get("/#{api_version}/user-data/")
+        Ohai::Log.debug("Mixin EC2: Fetching http://#{EC2_METADATA_ADDR}/#{best_api_version}/user-data/")
+        response = http_client.get("/#{best_api_version}/user-data/")
         response.code == "200" ? response.body : nil
       end
 
+      def fetch_dynamic_data
+        @fetch_dynamic_data ||= begin
+          response = http_client.get("/#{best_api_version}/dynamic/instance-identity/document/")
+
+          if json?(response.body) && response.code == "200"
+            FFI_Yajl::Parser.parse(response.body)
+          else
+            {}
+          end
+        end
+      end
+
       private
 
       def expand_path(file_name)
