@@ -26,32 +26,32 @@ module Ohai
       def collect_os
         case ::RbConfig::CONFIG["host_os"]
         when /aix(.+)$/
-          return "aix"
+          "aix"
         when /darwin(.+)$/
-          return "darwin"
+          "darwin"
         when /hpux(.+)$/
-          return "hpux"
+          "hpux"
         when /linux/
-          return "linux"
+          "linux"
         when /freebsd(.+)$/
-          return "freebsd"
+          "freebsd"
         when /openbsd(.+)$/
-          return "openbsd"
+          "openbsd"
         when /netbsd(.*)$/
-          return "netbsd"
+          "netbsd"
         when /dragonfly(.*)$/
-          return "dragonflybsd"
+          "dragonflybsd"
         when /solaris2/
-          return "solaris2"
+          "solaris2"
         when /mswin|mingw32|windows/
           # After long discussion in IRC the "powers that be" have come to a consensus
           # that no Windows platform exists that was not based on the
           # Windows_NT kernel, so we herby decree that "windows" will refer to all
           # platforms built upon the Windows_NT kernel and have access to win32 or win64
           # subsystems.
-          return "windows"
+          "windows"
         else
-          return ::RbConfig::CONFIG["host_os"]
+          ::RbConfig::CONFIG["host_os"]
         end
       end
 
