@@ -47,18 +47,18 @@ module ::Ohai::Mixin::SoftlayerMetadata
     full_url = "#{SOFTLAYER_API_QUERY_URL}/#{item}"
     u = URI(full_url)
     net = ::Net::HTTP.new(u.hostname, u.port)
-    net.ssl_version = "TLSv1"
+    net.ssl_version = :TLSv1_2
     net.use_ssl = true
     net.ca_file = ca_file_location
     res = net.get(u.request_uri)
     if res.code.to_i.between?(200, 299)
       res.body
     else
-      ::Ohai::Log.error("Unable to fetch item #{full_url}: status (#{res.code}) body (#{res.body})")
+      ::Ohai::Log.error("Mixin Softlayer: Unable to fetch item #{full_url}: status (#{res.code}) body (#{res.body})")
       nil
     end
   rescue => e
-    ::Ohai::Log.error("Unable to fetch softlayer metadata from #{u}: #{e.class}: #{e.message}")
+    ::Ohai::Log.error("Mixin Softlayer: Unable to fetch softlayer metadata from #{u}: #{e.class}: #{e.message}")
     raise e
   end
 end
