@@ -17,11 +17,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# eucalyptus metadata service is compatible with the ec2 service calls
-require "ohai/mixin/ec2_metadata"
-
 Ohai.plugin(:Eucalyptus) do
+  # eucalyptus metadata service is compatible with the ec2 service calls
+  require "ohai/mixin/ec2_metadata"
+  require "ohai/mixin/http_helper"
+
   include Ohai::Mixin::Ec2Metadata
+  include Ohai::Mixin::HttpHelper
 
   provides "eucalyptus"
   depends "network/interfaces"
@@ -53,14 +55,14 @@ Ohai.plugin(:Eucalyptus) do
   def looks_like_euca?
     # Try non-blocking connect so we don't "block" if
     # the metadata service doesn't respond
-    hint?("eucalyptus") || has_euca_mac? && can_metadata_connect?(Ohai::Mixin::Ec2Metadata::EC2_METADATA_ADDR, 80)
+    hint?("eucalyptus") || has_euca_mac? && can_socket_connect?(Ohai::Mixin::Ec2Metadata::EC2_METADATA_ADDR, 80)
   end
 
   collect_data do
     if looks_like_euca?
       Ohai::Log.debug("Plugin Eucalyptus: looks_like_euca? == true")
       eucalyptus Mash.new
-      self.fetch_metadata.each do |k, v|
+      fetch_metadata.each do |k, v|
         # Eucalyptus 3.4+ supports IAM roles and Instance Profiles much like AWS
         # https://www.eucalyptus.com/blog/2013/10/15/iam-roles-and-instance-profiles-eucalyptus-34
         #
@@ -71,7 +73,7 @@ Ohai.plugin(:Eucalyptus) do
         next if k == "iam" && !hint?("iam")
         eucalyptus[k] = v
       end
-      eucalyptus[:userdata] = self.fetch_userdata
+      eucalyptus[:userdata] = fetch_userdata
     else
       Ohai::Log.debug("Plugin Eucalyptus: looks_like_euca? == false")
       false
