@@ -25,10 +25,10 @@
 # limitations under the License.
 #
 
-require "socket"
-require "ipaddr"
-
 Ohai.plugin(:Hostname) do
+  require "socket"
+  require "ipaddr"
+
   provides "domain", "hostname", "fqdn", "machinename"
 
   # hostname : short hostname
@@ -47,14 +47,12 @@ Ohai.plugin(:Hostname) do
   # forward and reverse lookup to canonicalize FQDN (hostname -f equivalent)
   # this is ipv6-safe, works on ruby 1.8.7+
   def resolve_fqdn
-    begin
-      hostname = from_cmd("hostname")
-      addrinfo = Socket.getaddrinfo(hostname, nil).first
-      iaddr = IPAddr.new(addrinfo[3])
-      Socket.gethostbyaddr(iaddr.hton)[0]
-    rescue
-      nil
-    end
+    hostname = from_cmd("hostname")
+    addrinfo = Socket.getaddrinfo(hostname, nil).first
+    iaddr = IPAddr.new(addrinfo[3])
+    Socket.gethostbyaddr(iaddr.hton)[0]
+  rescue
+    nil
   end
 
   def collect_domain
@@ -76,24 +74,9 @@ Ohai.plugin(:Hostname) do
     end
   end
 
-  def get_fqdn_from_sigar
-    require "sigar"
-    sigar = Sigar.new
-    sigar.fqdn
-  end
-
-  def sigar_is_available?
-    begin
-      require "sigar"
-      true
-    rescue LoadError
-      false
-    end
-  end
-
   collect_data(:hpux, :default) do
     machinename from_cmd("hostname")
-    fqdn sigar_is_available? ? get_fqdn_from_sigar : resolve_fqdn
+    fqdn resolve_fqdn
     collect_hostname
     collect_domain
   end
@@ -105,13 +88,38 @@ Ohai.plugin(:Hostname) do
     collect_domain
   end
 
-  collect_data(:darwin, :netbsd, :openbsd, :dragonflybsd) do
+  collect_data(:netbsd, :openbsd, :dragonflybsd) do
     hostname from_cmd("hostname -s")
     fqdn resolve_fqdn
     machinename from_cmd("hostname")
     collect_domain
   end
 
+  collect_data(:darwin) do
+    hostname from_cmd("hostname -s")
+    machinename from_cmd("hostname")
+    begin
+      ourfqdn = resolve_fqdn
+      # Sometimes... very rarely, but sometimes, 'hostname --fqdn' falsely
+      # returns a blank string. WTF.
+      if ourfqdn.nil? || ourfqdn.empty?
+        Ohai::Log.debug("Plugin Hostname: hostname returned an empty string, retrying once.")
+        ourfqdn = resolve_fqdn
+      end
+
+      if ourfqdn.nil? || ourfqdn.empty?
+        Ohai::Log.debug("Plugin Hostname: hostname returned an empty string twice and will" +
+                        "not be set.")
+      else
+        fqdn ourfqdn
+      end
+    rescue
+      Ohai::Log.debug(
+        "Plugin Hostname: hostname returned an error, probably no domain set")
+    end
+    domain collect_domain
+  end
+
   collect_data(:freebsd) do
     hostname from_cmd("hostname -s")
     machinename from_cmd("hostname")
@@ -127,20 +135,19 @@ Ohai.plugin(:Hostname) do
       # Sometimes... very rarely, but sometimes, 'hostname --fqdn' falsely
       # returns a blank string. WTF.
       if ourfqdn.nil? || ourfqdn.empty?
-        Ohai::Log.debug("hostname --fqdn returned an empty string, retrying " +
+        Ohai::Log.debug("Plugin Hostname: hostname --fqdn returned an empty string, retrying " +
                         "once.")
         ourfqdn = from_cmd("hostname --fqdn")
       end
 
       if ourfqdn.nil? || ourfqdn.empty?
-        Ohai::Log.debug("hostname --fqdn returned an empty string twice and " +
+        Ohai::Log.debug("Plugin Hostname: hostname --fqdn returned an empty string twice and " +
                         "will not be set.")
       else
         fqdn ourfqdn
       end
     rescue
-      Ohai::Log.debug(
-        "hostname --fqdn returned an error, probably no domain set")
+      Ohai::Log.debug("Plugin Hostname: hostname --fqdn returned an error, probably no domain set")
     end
     domain collect_domain
   end
