@@ -24,6 +24,8 @@ Ohai.plugin(:IpScopes) do
     begin
       require "ipaddr_extensions"
 
+      Ohai::Log.warn("The IpScopes Ohai plugin has been deprecated and will be removed from Ohai 14 (April 2018).")
+
       network["interfaces"].keys.sort.each do |if_name|
         next if network["interfaces"][if_name]["addresses"].nil?
 
@@ -32,7 +34,7 @@ Ohai.plugin(:IpScopes) do
           begin
             attrs["ip_scope"] = address.to_ip.scope
 
-            if private_addr?(address) && !tunnel_iface?(interface)
+            if private_addr?(address) && !tunnel_iface?(interface) && !ppp_iface?(interface) && !docker_iface?(interface)
               privateaddress(address)
             end
           rescue ArgumentError
@@ -43,7 +45,7 @@ Ohai.plugin(:IpScopes) do
 
     rescue LoadError => e
       # our favourite gem is not installed. Boohoo.
-      Ohai::Log.debug("Plugin ip_scopes: cannot load gem, plugin disabled: #{e}")
+      Ohai::Log.debug("Plugin IpScopes: cannot load gem, plugin disabled: #{e}")
     end
   end
 
@@ -51,7 +53,15 @@ Ohai.plugin(:IpScopes) do
     address.to_ip.scope =~ /PRIVATE/
   end
 
-  def tunnel_iface?(interface)
+  def ppp_iface?(interface)
     interface["type"] == "ppp"
   end
+
+  def tunnel_iface?(interface)
+    interface["type"] == "tunl"
+  end
+
+  def docker_iface?(interface)
+    interface["type"] == "docker"
+  end
 end
