@@ -1,6 +1,8 @@
 #
 # Author:: Tim Smith <tsmith@limelight.com>
+# Author:: Phil Dibowitz <phild@ipomc.com>
 # Copyright:: Copyright (c) 2013-2014, Limelight Networks, Inc.
+# Copyright:: Copyright (c) 2017 Facebook, Inc.
 # Plugin:: mdadm
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -52,15 +54,52 @@ Ohai.plugin(:Mdadm) do
   collect_data(:linux) do
     # gather a list of all raid arrays
     if File.exist?("/proc/mdstat")
-      devices = []
+      devices = {}
       File.open("/proc/mdstat").each do |line|
-        devices << Regexp.last_match[1] if line =~ /(md[0-9]+)/
+        if line =~ /(md[0-9]+)/
+          device = Regexp.last_match[1]
+          pieces = line.split(/\s+/)
+          # there are variable numbers of fields until you hit the raid level
+          # everything after that is members...
+          # unless the array is inactive, in which case you don't get a raid
+          # level.
+          members = pieces.drop_while { |x| !x.start_with?("raid", "inactive") }
+          # and drop that too
+          members.shift unless members.empty?
+          devices[device] = {
+            "active" => [],
+            "spare" => [],
+            "journal" => nil,
+          }
+          members.each do |member|
+            # We want to match the device, and optionally the type
+            # most entries will look like:
+            #   sdc1[5]
+            # but some will look like:
+            #   sdc1[5](J)
+            # where the format is:
+            #   <device>[<number in array>](<type>)
+            # Type can be things like "J" for a journal device, or "S" for
+            # a spare device.
+            m = member.match(/(.+)\[\d+\](?:\((\w)\))?/)
+            member_device = m[1]
+            member_type = m[2]
+            case member_type
+            when "J"
+              devices[device]["journal"] = member_device
+            when "S"
+              devices[device]["spare"] << member_device
+            else
+              devices[device]["active"] << member_device
+            end
+          end
+        end
       end
 
       # create the mdadm mash and gather individual information if devices are present
       unless devices.empty?
         mdadm Mash.new
-        devices.sort.each do |device|
+        devices.keys.sort.each do |device|
           mdadm[device] = Mash.new
 
           # gather detailed information on the array
@@ -68,6 +107,9 @@ Ohai.plugin(:Mdadm) do
 
           # if the mdadm command was sucessful pass so.stdout to create_raid_device_mash to grab the tidbits we want
           mdadm[device] = create_raid_device_mash(so.stdout) if so.stdout
+          mdadm[device]["members"] = devices[device]["active"]
+          mdadm[device]["spares"] = devices[device]["spare"]
+          mdadm[device]["journal"] = devices[device]["journal"]
         end
       end
     end
