@@ -1,7 +1,7 @@
 #
 # Author:: Adam Jacob (<adam@chef.io>)
 # Author:: Chris Read <chris.read@gmail.com>
-# Copyright:: Copyright (c) 2008-2016 Chef Software, Inc.
+# Copyright:: Copyright (c) 2008-2017, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -37,16 +37,12 @@ Ohai.plugin(:Network) do
     File.exist? "/proc/net/if_inet6"
   end
 
-  def iproute2_binary_available?
-    ["/sbin/ip", "/usr/bin/ip", "/bin/ip"].any? { |path| File.exist?(path) }
-  end
-
-  def find_ethtool_binary
-    ["/sbin/ethtool", "/usr/sbin/ethtool"].find { |path| File.exist?(path) }
+  def ethtool_binary_path
+    @ethtool ||= which("ethtool")
   end
 
   def is_openvz?
-    ::File.directory?("/proc/vz")
+    @openvz ||= ::File.directory?("/proc/vz")
   end
 
   def is_openvz_host?
@@ -80,7 +76,7 @@ Ohai.plugin(:Network) do
     so = shell_out("ip -o -f #{family[:name]} route show table #{default_route_table}")
     so.stdout.lines do |line|
       line.strip!
-      Ohai::Log.debug("Parsing #{line}")
+      Ohai::Log.debug("Plugin Network: Parsing #{line}")
       if line =~ /\\/
         parts = line.split('\\')
         route_dest = parts.shift.strip
@@ -95,20 +91,21 @@ Ohai.plugin(:Network) do
         if route_ending =~ /\bdev\s+([^\s]+)\b/
           route_int = $1
         else
-          Ohai::Log.debug("Skipping route entry without a device: '#{line}'")
+          Ohai::Log.debug("Plugin Network: Skipping route entry without a device: '#{line}'")
           next
         end
         route_int = "venet0:0" if is_openvz? && !is_openvz_host? && route_int == "venet0" && iface["venet0:0"]
 
         unless iface[route_int]
-          Ohai::Log.debug("Skipping previously unseen interface from 'ip route show': #{route_int}")
+          Ohai::Log.debug("Plugin Network: Skipping previously unseen interface from 'ip route show': #{route_int}")
           next
         end
 
         route_entry = Mash.new(:destination => route_dest,
                                :family => family[:name])
         %w{via scope metric proto src}.each do |k|
-          route_entry[k] = $1 if route_ending =~ /\b#{k}\s+([^\s]+)\b/
+          # http://rubular.com/r/pwTNp65VFf
+          route_entry[k] = $1 if route_ending =~ /\b#{k}\s+([^\s]+)/
         end
 
         # a sanity check, especially for Linux-VServer, OpenVZ and LXC:
@@ -118,7 +115,7 @@ Ohai.plugin(:Network) do
           addr = iface[route_int][:addresses]
           unless addr.nil? || addr.has_key?(route_entry[:src]) ||
               addr.values.all? { |a| a["family"] != family[:name] }
-            Ohai::Log.debug("Skipping route entry whose src does not match the interface IP")
+            Ohai::Log.debug("Plugin Network: Skipping route entry whose src does not match the interface IP")
             next
           end
         end
@@ -141,22 +138,24 @@ Ohai.plugin(:Network) do
   # using a temporary var to hold routes and their interface name
   def parse_routes(family, iface)
     iface.collect do |i, iv|
-      iv[:routes].collect do |r|
-        r.merge(:dev => i) if r[:family] == family[:name]
-      end.compact if iv[:routes]
+      if iv[:routes]
+        iv[:routes].collect do |r|
+          r.merge(:dev => i) if r[:family] == family[:name]
+        end.compact
+      end
     end.compact.flatten
   end
 
   # determine layer 1 details for the interface using ethtool
   def ethernet_layer_one(iface)
-    return iface unless ethtool_binary = find_ethtool_binary
+    return iface unless ethtool_binary_path
     keys = %w{ Speed Duplex Port Transceiver Auto-negotiation MDI-X }
     iface.each_key do |tmp_int|
       next unless iface[tmp_int][:encapsulation] == "Ethernet"
-      so = shell_out("#{ethtool_binary} #{tmp_int}")
+      so = shell_out("#{ethtool_binary_path} #{tmp_int}")
       so.stdout.lines do |line|
         line.chomp!
-        Ohai::Log.debug("Parsing ethtool output: #{line}")
+        Ohai::Log.debug("Plugin Network: Parsing ethtool output: #{line}")
         line.lstrip!
         k, v = line.split(": ")
         next unless keys.include? k
@@ -173,11 +172,11 @@ Ohai.plugin(:Network) do
 
   # determine ring parameters for the interface using ethtool
   def ethernet_ring_parameters(iface)
-    return iface unless ethtool_binary = find_ethtool_binary
+    return iface unless ethtool_binary_path
     iface.each_key do |tmp_int|
       next unless iface[tmp_int][:encapsulation] == "Ethernet"
-      so = shell_out("#{ethtool_binary} -g #{tmp_int}")
-      Ohai::Log.debug("Parsing ethtool output: #{so.stdout}")
+      so = shell_out("#{ethtool_binary_path} -g #{tmp_int}")
+      Ohai::Log.debug("Plugin Network: Parsing ethtool output: #{so.stdout}")
       type = nil
       iface[tmp_int]["ring_params"] = {}
       so.stdout.lines.each do |line|
@@ -213,6 +212,31 @@ Ohai.plugin(:Network) do
         net_counters[tmp_int] = Mash.new unless net_counters[tmp_int]
       end
 
+      if line =~ /^\s+(ip6tnl|ipip)/
+        iface[tmp_int][:tunnel_info] = {}
+        words = line.split
+        words.each_with_index do |word, index|
+          case word
+          when "external"
+            iface[tmp_int][:tunnel_info][word] = true
+          when "any", "ipip6", "ip6ip6"
+            iface[tmp_int][:tunnel_info][:proto] = word
+          when "remote",
+               "local",
+               "encaplimit",
+               "hoplimit",
+               "tclass",
+               "flowlabel",
+               "addrgenmode",
+               "numtxqueues",
+               "numrxqueues",
+               "gso_max_size",
+               "gso_max_segs"
+            iface[tmp_int][:tunnel_info][word] = words[index + 1]
+          end
+        end
+      end
+
       if line =~ /(\d+)\s+(\d+)\s+(\d+)\s+(\d+)\s+(\d+)\s+(\d+)/
         int = on_rx ? :rx : :tx
         net_counters[tmp_int][int] = Mash.new unless net_counters[tmp_int][int]
@@ -380,7 +404,7 @@ Ohai.plugin(:Network) do
   end
 
   def interface_address_not_link_level?(iface, address)
-    !iface[:addresses][address][:scope].casecmp("link").zero?
+    !(iface[:addresses][address][:scope].casecmp("link") == 0)
   end
 
   def interface_valid_for_route?(iface, address, family)
@@ -462,14 +486,14 @@ Ohai.plugin(:Network) do
     else
       default_route_table = configuration(:default_route_table)
     end
-    Ohai::Log.debug("default route table is '#{default_route_table}'")
+    Ohai::Log.debug("Plugin Network: default route table is '#{default_route_table}'")
 
     # Match the lead line for an interface from iproute2
     # 3: eth0.11@eth0: <BROADCAST,MULTICAST,UP,LOWER_UP> mtu 1500 qdisc noqueue state UP
     # The '@eth0:' portion doesn't exist on primary interfaces and thus is optional in the regex
     IPROUTE_INT_REGEX = /^(\d+): ([0-9a-zA-Z@:\.\-_]*?)(@[0-9a-zA-Z]+|):\s/ unless defined? IPROUTE_INT_REGEX
 
-    if iproute2_binary_available?
+    if which("ip")
       # families to get default routes from
       families = [{
                     :name => "inet",
@@ -478,12 +502,14 @@ Ohai.plugin(:Network) do
                     :neighbour_attribute => :arp,
                   }]
 
-      families << {
-                    :name => "inet6",
-                    :default_route => "::/0",
-                    :default_prefix => :default_inet6,
-                    :neighbour_attribute => :neighbour_inet6,
-                  } if ipv6_enabled?
+      if ipv6_enabled?
+        families << {
+                      :name => "inet6",
+                      :default_route => "::/0",
+                      :default_prefix => :default_inet6,
+                      :neighbour_attribute => :neighbour_inet6,
+                    }
+      end
 
       parse_ip_addr(iface)
 
@@ -507,14 +533,14 @@ Ohai.plugin(:Network) do
                            else
                              "default_#{family[:name]}_interface"
                            end
-          Ohai::Log.debug("Unable to determine '#{attribute_name}' as no default routes were found for that interface family")
+          Ohai::Log.debug("Plugin Network: Unable to determine '#{attribute_name}' as no default routes were found for that interface family")
         else
           network["#{default_prefix}_interface"] = default_route[:dev]
-          Ohai::Log.debug("#{default_prefix}_interface set to #{default_route[:dev]}")
+          Ohai::Log.debug("Plugin Network: #{default_prefix}_interface set to #{default_route[:dev]}")
 
           # setting gateway to 0.0.0.0 or :: if the default route is a link level one
           network["#{default_prefix}_gateway"] = default_route[:via] ? default_route[:via] : family[:default_route].chomp("/0")
-          Ohai::Log.debug("#{default_prefix}_gateway set to #{network["#{default_prefix}_gateway"]}")
+          Ohai::Log.debug("Plugin Network: #{default_prefix}_gateway set to #{network["#{default_prefix}_gateway"]}")
 
           # deduce the default route the user most likely cares about to pick {ip,mac,ip6}address below
           favored_route = favored_default_route(routes, iface, default_route, family)
@@ -527,20 +553,20 @@ Ohai.plugin(:Network) do
             if family[:name] == "inet"
               ipaddress favored_route[:src]
               m = get_mac_for_interface(iface, favored_route[:dev])
-              Ohai::Log.debug("Overwriting macaddress #{macaddress} with #{m} from interface #{favored_route[:dev]}") if macaddress
+              Ohai::Log.debug("Plugin Network: Overwriting macaddress #{macaddress} with #{m} from interface #{favored_route[:dev]}") if macaddress
               macaddress m
             elsif family[:name] == "inet6"
               # this rarely does anything since we rarely have src for ipv6, so this usually falls back on the network plugin
               ip6address favored_route[:src]
               if macaddress
-                Ohai::Log.debug("Not setting macaddress from ipv6 interface #{favored_route[:dev]} because macaddress is already set")
+                Ohai::Log.debug("Plugin Network: Not setting macaddress from ipv6 interface #{favored_route[:dev]} because macaddress is already set")
               else
                 macaddress get_mac_for_interface(iface, favored_route[:dev])
               end
             end
           else
-            Ohai::Log.debug("the linux/network plugin was unable to deduce the favored default route for family '#{family[:name]}' despite finding a default route, and is not setting ipaddress/ip6address/macaddress. the network plugin may provide fallbacks.")
-            Ohai::Log.debug("this potential default route was excluded: #{default_route}")
+            Ohai::Log.debug("Plugin Network: Unable to deduce the favored default route for family '#{family[:name]}' despite finding a default route, and is not setting ipaddress/ip6address/macaddress. the network plugin may provide fallbacks.")
+            Ohai::Log.debug("Plugin Network: This potential default route was excluded: #{default_route}")
           end
         end
       end # end families.each
@@ -550,7 +576,7 @@ Ohai.plugin(:Network) do
         route_result = so.stdout.split($/).grep( /^0.0.0.0/ )[0].split( /[ \t]+/ )
         network[:default_gateway], network[:default_interface] = route_result.values_at(1, 7)
       rescue Ohai::Exceptions::Exec
-        Ohai::Log.debug("Unable to determine default interface")
+        Ohai::Log.debug("Plugin Network: Unable to determine default interface")
       end
 
       so = shell_out("ifconfig -a")
