@@ -34,7 +34,7 @@ Ohai.plugin(:Nodejs) do
         languages[:nodejs] = nodejs if nodejs[:version]
       end
     rescue Ohai::Exceptions::Exec
-      Ohai::Log.debug('Nodejs plugin: Could not shell_out "node -v". Skipping plugin')
+      Ohai::Log.debug('Plugin Nodejs: Could not shell_out "node -v". Skipping plugin')
     end
   end
 end
