@@ -14,9 +14,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-require "resolv"
-
 Ohai.plugin(:Rackspace) do
+  require "resolv"
   provides "rackspace"
 
   depends "kernel", "network/interfaces"
@@ -38,19 +37,33 @@ Ohai.plugin(:Rackspace) do
   def has_rackspace_metadata?
     so = shell_out("xenstore-read vm-data/provider_data/provider")
     if so.exitstatus == 0
-      so.stdout.strip.casecmp("rackspace").zero?
+      so.stdout.strip.casecmp("rackspace") == 0
     end
   rescue Ohai::Exceptions::Exec
     false
   end
 
+  # Checks for the rackspace manufacturer on Windows
+  # === Return
+  # true:: If the rackspace cloud can be identified
+  # false:: Otherwise
+  def has_rackspace_manufacturer?
+    return false unless RUBY_PLATFORM =~ /mswin|mingw32|windows/
+    require "wmi-lite/wmi"
+    wmi = WmiLite::Wmi.new
+    if wmi.first_of("Win32_ComputerSystem")["PrimaryOwnerName"] == "Rackspace"
+      Ohai::Log.debug("Plugin Rackspace: has_rackspace_manufacturer? == true")
+      return true
+    end
+  end
+
   # Identifies the rackspace cloud
   #
   # === Return
   # true:: If the rackspace cloud can be identified
   # false:: Otherwise
   def looks_like_rackspace?
-    hint?("rackspace") || has_rackspace_metadata? || has_rackspace_kernel?
+    hint?("rackspace") || has_rackspace_metadata? || has_rackspace_kernel? || has_rackspace_manufacturer?
   end
 
   # Names rackspace ip address
@@ -84,7 +97,7 @@ Ohai.plugin(:Rackspace) do
 
   # Get the rackspace region
   #
-  def get_region()
+  def get_region
     so = shell_out("xenstore-ls vm-data/provider_data")
     if so.exitstatus == 0
       so.stdout.split("\n").each do |line|
@@ -92,25 +105,25 @@ Ohai.plugin(:Rackspace) do
       end
     end
   rescue Ohai::Exceptions::Exec
-    Ohai::Log.debug("rackspace plugin: Unable to find xenstore-ls, cannot capture region information for Rackspace cloud")
+    Ohai::Log.debug("Plugin Rackspace: Unable to find xenstore-ls, cannot capture region information for Rackspace cloud")
     nil
   end
 
   # Get the rackspace instance_id
   #
-  def get_instance_id()
+  def get_instance_id
     so = shell_out("xenstore-read name")
     if so.exitstatus == 0
       rackspace[:instance_id] = so.stdout.gsub(/instance-/, "")
     end
   rescue Ohai::Exceptions::Exec
-    Ohai::Log.debug("rackspace plugin: Unable to find xenstore-read, cannot capture instance ID information for Rackspace cloud")
+    Ohai::Log.debug("Plugin Rackspace: Unable to find xenstore-read, cannot capture instance ID information for Rackspace cloud")
     nil
   end
 
   # Get the rackspace private networks
   #
-  def get_private_networks()
+  def get_private_networks
     so = shell_out("xenstore-ls vm-data/networking")
     if so.exitstatus == 0
       networks = []
@@ -119,7 +132,7 @@ Ohai.plugin(:Rackspace) do
         if so.exitstatus == 0
           networks.push(FFI_Yajl::Parser.new.parse(so.stdout))
         else
-          Ohai::Log.debug("rackspace plugin: Unable to capture custom private networking information for Rackspace cloud")
+          Ohai::Log.debug("Plugin Rackspace: Unable to capture custom private networking information for Rackspace cloud")
           return false
         end
       end
@@ -128,7 +141,7 @@ Ohai.plugin(:Rackspace) do
       networks.delete_if { |hash| hash["label"] == "public" }
     end
   rescue Ohai::Exceptions::Exec
-    Ohai::Log.debug("rackspace plugin: Unable to capture custom private networking information for Rackspace cloud")
+    Ohai::Log.debug("Plugin Rackspace: Unable to capture custom private networking information for Rackspace cloud")
     nil
   end
 
@@ -138,8 +151,8 @@ Ohai.plugin(:Rackspace) do
       rackspace Mash.new
       get_ip_address(:public_ip, :eth0)
       get_ip_address(:private_ip, :eth1)
-      get_region()
-      get_instance_id()
+      get_region
+      get_instance_id
       # public_ip + private_ip are deprecated in favor of public_ipv4 and local_ipv4 to standardize.
       rackspace[:public_ipv4] = rackspace[:public_ip]
       get_global_ipv6_address(:public_ipv6, :eth0)
