@@ -15,7 +15,7 @@
 # limitations under the License.
 
 Ohai.plugin(:Scala) do
-  provides "languages/scala", "languages/scala/sbt"
+  provides "languages/scala"
   depends "languages"
 
   collect_data(:default) do
@@ -23,24 +23,13 @@ Ohai.plugin(:Scala) do
     begin
       so = shell_out("scala -version")
       # Sample output:
-      # Scala code runner version 2.11.8 -- Copyright 2002-2016, LAMP/EPFL
+      # cat: /release: No such file or directory
+      # Scala code runner version 2.12.1 -- Copyright 2002-2016, LAMP/EPFL and Lightbend, Inc.
       if so.exitstatus == 0
-        scala[:version] = so.stderr.split[4]
+        scala[:version] = so.stderr.match(/.*version (\S*)/)[1]
       end
     rescue Ohai::Exceptions::Exec
-      Ohai::Log.debug('Scala plugin: Could not shell_out "scala -version". Skipping data')
-    end
-
-    # Check for sbt
-    begin
-      # sbt launcher version 0.13.7
-      so = shell_out("sbt --version")
-      if so.exitstatus == 0
-        scala[:sbt] = Mash.new
-        scala[:sbt][:version] = so.stdout.split[3]
-      end
-    rescue Ohai::Exceptions::Exec
-      Ohai::Log.debug('Scala plugin: Could not shell_out "sbt --version". Skipping data')
+      Ohai::Log.debug('Plugin Scala: Could not shell_out "scala -version". Skipping data')
     end
 
     languages[:scala] = scala unless scala.empty?
