@@ -54,11 +54,13 @@
 # inet6 fe80::203:baff:fe17:4444/128
 
 # Extracted from http://illumos.org/hcl/
-ETHERNET_ENCAPS = %w{ afe amd8111s arn atge ath bfe bge bnx bnxe ce cxgbe
-                      dmfe e1000g efe elxl emlxs eri hermon hme hxge igb
-                      iprb ipw iwh iwi iwk iwp ixgb ixgbe mwl mxfe myri10ge
-                      nge ntxn nxge pcn platform qfe qlc ral rge rtls rtw rwd
-                      rwn sfe tavor vr wpi xge yge aggr} unless defined?(ETHERNET_ENCAPS)
+unless defined?(ETHERNET_ENCAPS)
+  ETHERNET_ENCAPS = %w{ afe amd8111s arn atge ath bfe bge bnx bnxe ce cxgbe
+                        dmfe e1000g efe elxl emlxs eri hermon hme hxge igb
+                        iprb ipw iwh iwi iwk iwp ixgb ixgbe mwl mxfe myri10ge
+                        nge ntxn nxge pcn platform qfe qlc ral rge rtls rtw rwd
+                        rwn sfe tavor vr wpi xge yge aggr}
+end
 
 Ohai.plugin(:Network) do
   provides "network", "network/interfaces"
@@ -101,7 +103,8 @@ Ohai.plugin(:Network) do
     cint = nil
 
     so.stdout.lines do |line|
-      if line =~ /^([0-9a-zA-Z\.\:\-]+)\S/
+      # regex: http://rubular.com/r/Iag7JLVTVe
+      if line =~ /^([0-9a-zA-Z\.\:\-]+): \S+ mtu (\d+) index (\d+)/
         cint = $1
         iface[cint] = Mash.new unless iface[cint]
         iface[cint][:mtu] = $2
@@ -178,11 +181,11 @@ Ohai.plugin(:Network) do
           else
             matches[:name]
           end
-        Ohai::Log.debug("found interface device: #{network[:default_interface]} #{matches[:name]}")
+        Ohai::Log.debug("Plugin Network: found interface device: #{network[:default_interface]} #{matches[:name]}")
       end
       matches = /gateway: (\S+)/.match(line)
       if matches
-        Ohai::Log.debug("found gateway: #{matches[1]}")
+        Ohai::Log.debug("Plugin Network: found gateway: #{matches[1]}")
         network[:default_gateway] = matches[1]
       end
     end
