@@ -18,9 +18,8 @@
 # limitations under the License.
 #
 
-require "ohai/mixin/dmi_decode"
-
 Ohai.plugin(:Virtualization) do
+  require "ohai/mixin/dmi_decode"
   include Ohai::Mixin::DmiDecode
   provides "virtualization"
 
@@ -74,7 +73,11 @@ Ohai.plugin(:Virtualization) do
 
       if zones.length == 1
         first_zone = zones.keys[0]
-        unless first_zone == "global"
+        if first_zone == "global"
+          virtualization[:system] = "zone"
+          virtualization[:role] = "host"
+          virtualization[:systems][:zone] = "host"
+        else
           virtualization[:system] = "zone"
           virtualization[:role] = "guest"
           virtualization[:systems][:zone] = "guest"
