@@ -17,7 +17,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-require File.expand_path(File.dirname(__FILE__) + "/../../spec_helper.rb")
+require_relative "../../spec_helper.rb"
 require "ohai/mixin/softlayer_metadata"
 
 describe ::Ohai::Mixin::SoftlayerMetadata do
@@ -36,7 +36,7 @@ describe ::Ohai::Mixin::SoftlayerMetadata do
   end
 
   context "fetch_metadata" do
-    it "riases error if softlayer api query results with error" do
+    it "raises error if softlayer api query results with error" do
       http_mock = double("http", { :ssl_version= => true, :use_ssl= => true, :ca_file= => true })
       allow(http_mock).to receive(:get).and_raise(StandardError.new("API return fake error"))
       allow(::Net::HTTP).to receive(:new).with("api.service.softlayer.com", 443).and_return(http_mock)
