@@ -16,26 +16,23 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-require File.expand_path(File.dirname(__FILE__) + "/../../../spec_helper.rb")
+require_relative "../../../spec_helper.rb"
 
 describe Ohai::System, "Aix plugin uptime" do
 
   before(:each) do
     @plugin = get_plugin("aix/uptime")
     allow(@plugin).to receive(:collect_os).and_return(:aix)
-    allow(Time).to receive_message_chain(:now, :to_i).and_return(1412072511)
-    allow(Time).to receive_message_chain(:now, :zone).and_return("IST")
-    allow(DateTime).to receive_message_chain(:parse, :strftime, :to_i).and_return(1411561320)
-    allow(@plugin).to receive(:shell_out).with("who -b").and_return(mock_shell_out(0, "   .        system boot Sep 24 17:52", nil))
-
+    allow(@plugin).to receive(:shell_out).and_call_original
+    allow(@plugin).to receive(:shell_out).with("LC_ALL=POSIX ps -o etime= -p 1").and_return(mock_shell_out(0, "1148-20:54:50", nil))
     @plugin.run
   end
 
-  it "should set uptime_seconds to uptime" do
-    expect(@plugin[:uptime_seconds]).to eq(511191)
+  it "should set uptime_seconds to uptime with days" do
+    expect(@plugin[:uptime_seconds]).to eq(99262490)
   end
 
-  it "should set uptime to a human readable date" do
-    expect(@plugin[:uptime]).to eq("5 days 21 hours 59 minutes 51 seconds")
+  it "should set uptime to a human readable date with days" do
+    expect(@plugin[:uptime]).to eq("1148 days 20 hours 54 minutes 50 seconds")
   end
 end
