@@ -16,7 +16,7 @@
 # limitations under the License.
 #
 
-require File.expand_path(File.dirname(__FILE__) + "/../../spec_helper.rb")
+require_relative "../../spec_helper.rb"
 
 # NOTE: These data lines must be prefixed with one or two tabs, not spaces.
 DMI_OUT = <<-EOS
