@@ -14,7 +14,7 @@
 # limitations under the License.
 #
 
-require File.expand_path(File.join(File.dirname(__FILE__), "..", "..", "/spec_helper.rb"))
+require_relative "../../spec_helper.rb"
 
 describe Ohai::System, "plugin elixir" do
   let(:plugin) { get_plugin("elixir") }
