@@ -15,7 +15,7 @@
 # limitations under the License.
 #
 
-require File.expand_path(File.dirname(__FILE__) + "/../../spec_helper.rb")
+require_relative "../../spec_helper.rb"
 
 describe Ohai::System, "plugin linode" do
   let(:plugin) { get_plugin("linode") }
