@@ -17,14 +17,8 @@
 #  limitations under the License.
 #
 
-require File.expand_path(File.dirname(__FILE__) + "/../../../spec_helper.rb")
-
-begin
-  require "ipaddress"
-rescue LoadError => e
-  puts "The linux network plugin spec tests will fail without the 'ipaddress' library/gem.\n\n"
-  raise e
-end
+require_relative "../../../spec_helper.rb"
+require "ipaddress"
 
 describe Ohai::System, "Linux Network Plugin" do
   let(:plugin) { get_plugin("linux/network") }
@@ -240,6 +234,10 @@ EOM
        valid_lft forever preferred_lft forever
 13: fwdintf: <MULTICAST,NOARP,UP,LOWER_UP> mtu 1496 qdisc pfifo_fast state UNKNOWN group default qlen 1000
     link/ether 00:00:00:00:00:0a brd ff:ff:ff:ff:ff:ff
+14: ip6tnl0@NONE: <NOARP,UP,LOWER_UP> mtu 1452 qdisc noqueue state UNKNOWN group default qlen 1
+    link/tunnel6 :: brd ::
+    inet6 fe80::f47a:2aff:fef0:c6ef/64 scope link
+       valid_lft forever preferred_lft forever
 EOM
   end
 
@@ -300,6 +298,13 @@ EOM
     0          0        0       0       0       0
     TX: bytes  packets  errors  dropped carrier collsns
     140        2        0       1       0       0
+14: ip6tnl0@NONE: <NOARP> mtu 1452 qdisc noop state DOWN mode DEFAULT group default qlen 1
+    link/tunnel6 :: brd :: promiscuity 0
+    ip6tnl ip6ip6 remote :: local :: encaplimit 0 hoplimit 0 tclass 0x00 flowlabel 0x00000 (flowinfo 0x00000000) addrgenmode eui64 numtxqueues 1 numrxqueues 1 gso_max_size 65536 gso_max_segs 65535
+    RX: bytes  packets  errors  dropped overrun mcast
+    0          0        0       0       0       0
+    TX: bytes  packets  errors  dropped carrier collsns
+    0          0        0       0       0       0
 EOM
   end
 
@@ -383,26 +388,6 @@ EOM
     allow(plugin).to receive(:shell_out).with(/ethtool [^\-]/).and_return(mock_shell_out(0, linux_ethtool, ""))
   end
 
-  describe "#iproute2_binary_available?" do
-    ["/sbin/ip", "/usr/bin/ip", "/bin/ip"].each do |path|
-      it "accepts #{path}" do
-        allow(File).to receive(:exist?).and_return(false)
-        allow(File).to receive(:exist?).with(path).and_return(true)
-        expect(plugin.iproute2_binary_available?).to be_truthy
-      end
-    end
-  end
-
-  describe "#find_ethtool_binary" do
-    ["/sbin/ethtool", "/usr/sbin/ethtool"].each do |path|
-      it "accepts #{path}" do
-        allow(File).to receive(:exist?).and_return(false)
-        allow(File).to receive(:exist?).with(path).and_return(true)
-        expect(plugin.find_ethtool_binary).to end_with("/ethtool")
-      end
-    end
-  end
-
   describe "#interface_has_no_addresses_in_family?" do
     context "when interface has no addresses" do
       let(:iface) { {} }
@@ -561,8 +546,8 @@ EOM
   %w{ifconfig iproute2}.each do |network_method|
     describe "gathering IP layer address info via #{network_method}" do
       before(:each) do
-        allow(plugin).to receive(:iproute2_binary_available?).and_return( network_method == "iproute2" )
-        allow(plugin).to receive(:find_ethtool_binary).and_return( "/sbin/ethtool" )
+        allow(plugin).to receive(:which).with("ip").and_return( network_method == "iproute2" ? "/sbin/ip" : false )
+        allow(plugin).to receive(:which).with("ethtool").and_return( "/sbin/ethtool" )
         plugin.run
       end
 
@@ -572,7 +557,11 @@ EOM
       end
 
       it "detects the interfaces" do
-        expect(plugin["network"]["interfaces"].keys.sort).to eq(["eth0", "eth0.11", "eth0.151", "eth0.152", "eth0.153", "eth0:5", "eth3", "foo:veth0@eth0", "fwdintf", "lo", "ovs-system", "tun0", "venet0", "venet0:0", "xapi1"])
+        if network_method == "iproute2"
+          expect(plugin["network"]["interfaces"].keys.sort).to eq(["eth0", "eth0.11", "eth0.151", "eth0.152", "eth0.153", "eth0:5", "eth3", "foo:veth0@eth0", "fwdintf", "ip6tnl0", "lo", "ovs-system", "tun0", "venet0", "venet0:0", "xapi1"])
+        else
+          expect(plugin["network"]["interfaces"].keys.sort).to eq(["eth0", "eth0.11", "eth0.151", "eth0.152", "eth0.153", "eth0:5", "eth3", "foo:veth0@eth0", "fwdintf", "lo", "ovs-system", "tun0", "venet0", "venet0:0", "xapi1"])
+        end
       end
 
       it "detects the layer one details of an ethernet interface" do
@@ -676,11 +665,32 @@ EOM
         expect(plugin["network"]["interfaces"]["eth0"]["arp"]["10.116.201.1"]).to eq("fe:ff:ff:ff:ff:ff")
       end
 
+      if network_method == "iproute2"
+        it "detects the tunnel information" do
+          expect(plugin["network"]["interfaces"]["ip6tnl0"]["tunnel_info"]).to eq(
+            {
+              "proto" => "ip6ip6",
+              "remote" => "::",
+              "local" => "::",
+              "encaplimit" => "0",
+              "hoplimit" => "0",
+              "tclass" => "0x00",
+              "flowlabel" => "0x00000",
+              "addrgenmode" => "eui64",
+              "numtxqueues" => "1",
+              "numrxqueues" => "1",
+              "gso_max_size" => "65536",
+              "gso_max_segs" => "65535",
+            }
+          )
+        end
+      end
     end
 
     describe "gathering interface counters via #{network_method}" do
       before(:each) do
-        allow(plugin).to receive(:iproute2_binary_available?).and_return( network_method == "iproute2" )
+        allow(plugin).to receive(:which).with("ip").and_return(network_method == "iproute2" ? "/sbin/ip" : false)
+        allow(plugin).to receive(:which).with("ethtool").and_return("/sbin/ethtool")
         plugin.run
       end
 
@@ -718,7 +728,8 @@ EOM
 
     describe "setting the node's default IP address attribute with #{network_method}" do
       before(:each) do
-        allow(plugin).to receive(:iproute2_binary_available?).and_return( network_method == "iproute2" )
+        allow(plugin).to receive(:which).with("ip").and_return(network_method == "iproute2" ? "/sbin/ip" : false)
+        allow(plugin).to receive(:which).with("ethtool").and_return("/sbin/ethtool")
         plugin.run
       end
 
@@ -796,9 +807,9 @@ EOM
 
   describe "for newer network features using iproute2 only" do
     before(:each) do
-      allow(File).to receive(:exist?).with("/sbin/ip").and_return(true) # iproute2 only
+      allow(plugin).to receive(:which).with("ip").and_return("/sbin/ip")
+      allow(plugin).to receive(:which).with("ethtool").and_return( "/sbin/ethtool" )
       allow(File).to receive(:exist?).with("/proc/net/if_inet6").and_return(true) # ipv6 is enabled
-      allow(File).to receive(:exist?).with("/sbin/ethtool").and_return(true) # ethtool is available
       plugin.run
     end
 
@@ -1325,7 +1336,7 @@ EOM
         end
 
         it "logs a message and skips previously unseen interfaces in 'ip route show'" do
-          expect(Ohai::Log).to receive(:debug).with("Skipping previously unseen interface from 'ip route show': virbr0").once
+          expect(Ohai::Log).to receive(:debug).with(/Skipping previously unseen interface from 'ip route show': virbr0/).once
           allow(Ohai::Log).to receive(:debug) # Catches the 'Loading plugin network' type messages
           plugin.run
         end
