@@ -1,6 +1,6 @@
 #
 # Author:: Adam Jacob (<adam@chef.io>)
-# Copyright:: Copyright (c) 2008-2016 Chef Software, Inc.
+# Copyright:: Copyright (c) 2008-2017, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,8 +16,7 @@
 # limitations under the License.
 #
 
-require File.expand_path(File.dirname(__FILE__) + "/../../../spec_helper.rb")
-require File.expand_path(File.dirname(__FILE__) + "/../../../spec_helper.rb")
+require_relative "../../../spec_helper.rb"
 
 describe Ohai::System, "Linux plugin platform" do
 
@@ -36,7 +35,10 @@ describe Ohai::System, "Linux plugin platform" do
   let(:have_parallels_release) { false }
   let(:have_raspi_config) { false }
   let(:have_os_release) { false }
+  let(:have_usr_lib_os_release) { false }
   let(:have_cisco_release) { false }
+  let(:have_f5_release) { false }
+  let(:have_cumulus_dir) { false }
 
   before(:each) do
     @plugin = get_plugin("linux/platform")
@@ -57,7 +59,10 @@ describe Ohai::System, "Linux plugin platform" do
     allow(File).to receive(:exist?).with("/etc/parallels-release").and_return(have_parallels_release)
     allow(File).to receive(:exist?).with("/usr/bin/raspi-config").and_return(have_raspi_config)
     allow(File).to receive(:exist?).with("/etc/os-release").and_return(have_os_release)
+    allow(File).to receive(:exist?).with("/etc/f5-release").and_return(have_f5_release)
+    allow(File).to receive(:exist?).with("/usr/lib/os-release").and_return(have_usr_lib_os_release)
     allow(File).to receive(:exist?).with("/etc/shared/os-release").and_return(have_cisco_release)
+    allow(Dir).to receive(:exist?).with("/etc/cumulus").and_return(have_cumulus_dir)
 
     allow(File).to receive(:read).with("PLEASE STUB ALL File.read CALLS")
   end
@@ -112,7 +117,7 @@ describe Ohai::System, "Linux plugin platform" do
       @plugin[:lsb][:release] = "2011.09"
       @plugin.run
       expect(@plugin[:platform]).to eq("amazon")
-      expect(@plugin[:platform_family]).to eq("rhel")
+      expect(@plugin[:platform_family]).to eq("amazon")
     end
 
     it "should set platform to scientific when [:lsb][:id] contains ScientificSL" do
@@ -171,6 +176,41 @@ describe Ohai::System, "Linux plugin platform" do
         expect(@plugin[:platform_family]).to eq("debian")
       end
     end
+
+    context "on cumulus" do
+
+      let(:have_cumulus_dir) { true }
+      let(:cumulus_release_content) do
+        <<-OS_RELEASE
+NAME="Cumulus Linux"
+VERSION_ID=3.1.2
+VERSION="Cumulus Linux 3.1.2"
+PRETTY_NAME="Cumulus Linux"
+ID=cumulus-linux
+ID_LIKE=debian
+CPE_NAME=cpe:/o:cumulusnetworks:cumulus_linux:3.1.2
+HOME_URL="http://www.cumulusnetworks.com/"
+SUPPORT_URL="http://support.cumulusnetworks.com/"
+
+OS_RELEASE
+      end
+
+      before(:each) do
+        expect(File).to receive(:read).with("/etc/cumulus/etc.replace/os-release").and_return(cumulus_release_content)
+      end
+
+      # Cumulus is a debian derivative
+      it "should detect Cumulus as itself with debian as the family" do
+        @plugin.run
+        expect(@plugin[:platform]).to eq("cumulus")
+        expect(@plugin[:platform_family]).to eq("debian")
+      end
+
+      it "should detect Cumulus platform_version" do
+        @plugin.run
+        expect(@plugin[:platform_version]).to eq("3.1.2")
+      end
+    end
   end
 
   describe "on slackware" do
@@ -187,6 +227,12 @@ describe Ohai::System, "Linux plugin platform" do
       expect(@plugin[:platform]).to eq("slackware")
       expect(@plugin[:platform_family]).to eq("slackware")
     end
+
+    it "should set platform_version on slackware" do
+      expect(File).to receive(:read).with("/etc/slackware-version").and_return("Slackware 12.0.0")
+      @plugin.run
+      expect(@plugin[:platform_version]).to eq("12.0.0")
+    end
   end
 
   describe "on arch" do
@@ -265,6 +311,23 @@ describe Ohai::System, "Linux plugin platform" do
     end
   end
 
+  describe "on f5 big-ip" do
+
+    let(:have_f5_release) { true }
+
+    before(:each) do
+      @plugin.lsb = nil
+    end
+
+    it "should set platform to bigip" do
+      expect(File).to receive(:read).with("/etc/f5-release").and_return("BIG-IP release 13.0.0 (Final)")
+      @plugin.run
+      expect(@plugin[:platform]).to eq("bigip")
+      expect(@plugin[:platform_family]).to eq("rhel")
+      expect(@plugin[:platform_version]).to eq("13.0.0")
+    end
+  end
+
   describe "on exherbo" do
 
     let(:have_exherbo_release) { true }
@@ -316,7 +379,7 @@ describe Ohai::System, "Linux plugin platform" do
       it "should set the platform_family to rhel if the LSB name is amazon-ish" do
         @plugin[:lsb][:id] = "Amazon"
         @plugin.run
-        expect(@plugin[:platform_family]).to eq("rhel")
+        expect(@plugin[:platform_family]).to eq("amazon")
       end
 
       it "should set the platform_family to fedora if the LSB name is fedora-ish" do
@@ -387,6 +450,14 @@ describe Ohai::System, "Linux plugin platform" do
         expect(@plugin[:platform_version].to_i).to eq(13)
       end
 
+      it "should read the platform as clearos and version as 7.3" do
+        expect(File).to receive(:read).with("/etc/redhat-release").and_return("ClearOS release 7.3.0 (Final)")
+        @plugin.run
+        expect(@plugin[:platform]).to eq("clearos")
+        expect(@plugin[:platform_family]).to eq("rhel")
+        expect(@plugin[:platform_version].to_f).to eq(7.3)
+      end
+
       # https://github.com/chef/ohai/issues/560
       # Issue is seen on EL7, so that's what we're testing.
       context "on versions that have /etc/os-release" do
@@ -811,4 +882,35 @@ CISCO_RELEASE
       expect(@plugin[:platform_version]).to eq("6.0.0.14I")
     end
   end
+
+  describe "on clearlinux" do
+    let(:have_usr_lib_os_release) { true }
+    let(:usr_lib_os_release_content) do
+      <<-CLEARLINUX_RELEASE
+NAME="Clear Linux Software for Intel Architecture"
+VERSION=1
+ID=clear-linux-os
+VERSION_ID=16140
+PRETTY_NAME="Clear Linux OS for Intel Architecture"
+ANSI_COLOR="1;35"
+HOME_URL="https://clearlinux.org"
+SUPPORT_URL="https://clearlinux.org"
+BUG_REPORT_URL="mailto:dev@lists.clearlinux.org"
+PRIVACY_POLICY_URL="http://www.intel.com/privacy"
+CLEARLINUX_RELEASE
+    end
+
+    before do
+      expect(File).to receive(:read).with("/usr/lib/os-release").and_return(usr_lib_os_release_content)
+    end
+
+    it "should set platform to clearlinux and platform_family to clearlinux" do
+      @plugin.lsb = nil
+      @plugin.run
+
+      expect(@plugin[:platform]).to eq("clearlinux")
+      expect(@plugin[:platform_family]).to eq("clearlinux")
+      expect(@plugin[:platform_version]).to eq("16140")
+    end
+  end
 end
