@@ -16,7 +16,7 @@
 # limitations under the License.
 #
 
-require File.expand_path(File.dirname(__FILE__) + "/../../../spec_helper.rb")
+require_relative "../../../spec_helper.rb"
 
 describe Ohai::System, "Linux virtualization platform" do
   let(:plugin) { get_plugin("linux/virtualization") }
@@ -40,10 +40,11 @@ describe Ohai::System, "Linux virtualization platform" do
     allow(File).to receive(:exist?).with("/sys/devices/virtual/misc/kvm").and_return(false)
     allow(File).to receive(:exist?).with("/dev/lxd/sock").and_return(false)
     allow(File).to receive(:exist?).with("/var/lib/lxd/devlxd").and_return(false)
+    allow(File).to receive(:exist?).with("/proc/1/environ").and_return(false)
 
     # default the which wrappers to nil
-    allow(plugin).to receive(:lxc_version_exists?).and_return(false)
-    allow(plugin).to receive(:docker_exists?).and_return(false)
+    allow(plugin).to receive(:which).with("lxc-version").and_return(nil)
+    allow(plugin).to receive(:which).with("lxc-start").and_return(nil)
     allow(plugin).to receive(:nova_exists?).and_return(false)
   end
 
@@ -345,6 +346,25 @@ OUTPUT
       expect(plugin[:virtualization][:systems][:bhyve]).to eq("guest")
     end
 
+    it "sets veertu guest if dmidecode detects Veertu" do
+      veertu_dmidecode = <<-VEERTU
+System Information
+  Manufacturer: Veertu
+  Product Name: Veertu
+  Version: Not Specified
+  Serial Number: Not Specified
+  UUID: Not Settable
+  Wake-up Type: Power Switch
+  SKU Number: Not Specified
+  Family: Not Specified
+VEERTU
+      allow(plugin).to receive(:shell_out).with("dmidecode").and_return(mock_shell_out(0, veertu_dmidecode, ""))
+      plugin.run
+      expect(plugin[:virtualization][:system]).to eq("veertu")
+      expect(plugin[:virtualization][:role]).to eq("guest")
+      expect(plugin[:virtualization][:systems][:veertu]).to eq("guest")
+    end
+
     it "should run dmidecode and not set virtualization if nothing is detected" do
       allow(plugin).to receive(:shell_out).with("dmidecode").and_return(mock_shell_out(0, "", ""))
       plugin.run
@@ -534,6 +554,7 @@ CGROUP
 2:cpu:/Charlie
 1:cpuset:/Charlie
 CGROUP
+      allow(File).to receive(:read).with("/proc/1/environ").and_return("")
       expect(File).to receive(:exist?).with("/proc/self/cgroup").and_return(true)
       allow(File).to receive(:read).with("/proc/self/cgroup").and_return(self_cgroup)
       plugin.run
@@ -554,10 +575,19 @@ CGROUP
 CGROUP
         expect(File).to receive(:exist?).with("/proc/self/cgroup").and_return(true)
         allow(File).to receive(:read).with("/proc/self/cgroup").and_return(self_cgroup)
+        allow(File).to receive(:read).with("/proc/1/environ").and_return("")
       end
 
       it "sets lxc host if lxc-version exists" do
-        allow(plugin).to receive(:lxc_version_exists?).and_return("/usr/bin/lxc-version")
+        allow(plugin).to receive(:which).with("lxc-start").and_return("/usr/bin/lxc-version")
+        plugin.run
+        expect(plugin[:virtualization][:system]).to eq("lxc")
+        expect(plugin[:virtualization][:role]).to eq("host")
+        expect(plugin[:virtualization][:systems][:lxc]).to eq("host")
+      end
+
+      it "sets lxc host if lxc-start exists" do
+        allow(plugin).to receive(:which).with("lxc-start").and_return("/usr/bin/lxc-start")
         plugin.run
         expect(plugin[:virtualization][:system]).to eq("lxc")
         expect(plugin[:virtualization][:role]).to eq("host")
@@ -565,7 +595,7 @@ CGROUP
       end
 
       it "does not set the old virtualization attributes if they are already set" do
-        allow(plugin).to receive(:lxc_version_exists?).and_return("/usr/bin/lxc-version")
+        allow(plugin).to receive(:which).with("lxc-version").and_return("/usr/bin/lxc-version")
         plugin[:virtualization] = Mash.new
         plugin[:virtualization][:system] = "the cloud"
         plugin[:virtualization][:role] = "cumulonimbus"
@@ -574,14 +604,21 @@ CGROUP
         expect(plugin[:virtualization][:role]).not_to eq("host")
       end
 
-      it "does not set lxc host if lxc-version does not exist" do
-        allow(plugin).to receive(:lxc_version_exists?).and_return(false)
+      it "does not set lxc host if neither lxc-version nor lxc-start exists" do
         plugin.run
         expect(plugin[:virtualization][:system]).to be_nil
         expect(plugin[:virtualization][:role]).to be_nil
         expect(plugin[:virtualization]).to eq({ "systems" => {} })
       end
 
+      it "sets lxc guest if /proc/1/environ has lxccontainer string in it" do
+        one_environ = "container=lxccontainer_ttys=/dev/pts/0 /dev/pts/1 /dev/pts/2 /dev/pts/3".chomp
+        allow(File).to receive(:read).with("/proc/1/environ").and_return(one_environ)
+        plugin.run
+        expect(plugin[:virtualization][:system]).to eq("lxc")
+        expect(plugin[:virtualization][:role]).to eq("guest")
+      end
+
     end
 
     it "does not set virtualization if /proc/self/cgroup isn't there" do
@@ -591,6 +628,18 @@ CGROUP
     end
   end
 
+  describe "when we are checking for systemd-nspawn" do
+    it "sets nspawn guest if /proc/1/environ has nspawn string in it" do
+      allow(File).to receive(:exist?).with("/proc/self/cgroup").and_return(true)
+      one_environ = "container=systemd-nspawn_ttys=/dev/pts/0 /dev/pts/1 /dev/pts/2 /dev/pts/3".chomp
+      allow(File).to receive(:read).with("/proc/1/environ").and_return(one_environ)
+      allow(File).to receive(:read).with("/proc/self/cgroup").and_return("")
+      plugin.run
+      expect(plugin[:virtualization][:system]).to eq("nspawn")
+      expect(plugin[:virtualization][:role]).to eq("guest")
+    end
+  end
+
   describe "when we are checking for docker" do
     it "sets docker guest if /proc/self/cgroup exist and there are /docker/<hexadecimal> mounts" do
       self_cgroup = <<-CGROUP
@@ -630,6 +679,30 @@ CGROUP
       expect(plugin[:virtualization][:systems][:docker]).to eq("guest")
     end
 
+    it "sets docker guest if /proc/self/cgroup exist and there are /docker/docker-ce/<hexadecimal> mounts" do
+      self_cgroup = <<-CGROUP
+13:name=systemd:/docker-ce/docker/b15b85d19304436488a78d06afeb108d94b20bb6898d852b65cad51bd7dc9468
+12:pids:/docker-ce/docker/b15b85d19304436488a78d06afeb108d94b20bb6898d852b65cad51bd7dc9468
+11:hugetlb:/docker-ce/docker/b15b85d19304436488a78d06afeb108d94b20bb6898d852b65cad51bd7dc9468
+10:net_prio:/docker-ce/docker/b15b85d19304436488a78d06afeb108d94b20bb6898d852b65cad51bd7dc9468
+9:perf_event:/docker-ce/docker/b15b85d19304436488a78d06afeb108d94b20bb6898d852b65cad51bd7dc9468
+8:net_cls:/docker-ce/docker/b15b85d19304436488a78d06afeb108d94b20bb6898d852b65cad51bd7dc9468
+7:freezer:/docker-ce/docker/b15b85d19304436488a78d06afeb108d94b20bb6898d852b65cad51bd7dc9468
+6:devices:/docker-ce/docker/b15b85d19304436488a78d06afeb108d94b20bb6898d852b65cad51bd7dc9468
+5:memory:/docker-ce/docker/b15b85d19304436488a78d06afeb108d94b20bb6898d852b65cad51bd7dc9468
+4:blkio:/docker-ce/docker/b15b85d19304436488a78d06afeb108d94b20bb6898d852b65cad51bd7dc9468
+3:cpuacct:/docker-ce/docker/b15b85d19304436488a78d06afeb108d94b20bb6898d852b65cad51bd7dc9468
+2:cpu:/docker-ce/docker/b15b85d19304436488a78d06afeb108d94b20bb6898d852b65cad51bd7dc9468
+1:cpuset:/docker-ce/docker/b15b85d19304436488a78d06afeb108d94b20bb6898d852b65cad51bd7dc9468
+CGROUP
+      allow(File).to receive(:exist?).with("/proc/self/cgroup").and_return(true)
+      allow(File).to receive(:read).with("/proc/self/cgroup").and_return(self_cgroup)
+      plugin.run
+      expect(plugin[:virtualization][:system]).to eq("docker")
+      expect(plugin[:virtualization][:role]).to eq("guest")
+      expect(plugin[:virtualization][:systems][:docker]).to eq("guest")
+    end
+
     # Relevant at least starting docker 1.6.2, kernel 4.0.5 & systemd 224-1.
     # Doi not exactly know which software/version really matters here.
     it "should set docker guest if /proc/self/cgroup exists and there are /system.slice/docker-<hexadecimal> mounts (systemd managed cgroup)" do
@@ -664,6 +737,7 @@ CGROUP
 CGROUP
       allow(File).to receive(:exist?).with("/proc/self/cgroup").and_return(true)
       allow(File).to receive(:read).with("/proc/self/cgroup").and_return(self_cgroup)
+      allow(File).to receive(:read).with("/proc/1/environ").and_return("")
       plugin.run
       expect(plugin[:virtualization]).to eq({ "systems" => {} })
     end
@@ -689,7 +763,6 @@ CGROUP
     end
 
     it "does not set the old virtualization attributes if they are already set" do
-      allow(plugin).to receive(:docker_exists?).and_return("/usr/bin/docker")
       plugin[:virtualization] = Mash.new
       plugin[:virtualization][:system] = "the cloud"
       plugin[:virtualization][:role] = "cumulonimbus"
@@ -699,7 +772,6 @@ CGROUP
     end
 
     it "does not set docker host if docker does not exist" do
-      allow(plugin).to receive(:docker_exists?).and_return(false)
       plugin.run
       expect(plugin[:virtualization][:system]).to be_nil
       expect(plugin[:virtualization][:role]).to be_nil
