@@ -17,7 +17,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-require File.expand_path(File.dirname(__FILE__) + "/../../spec_helper.rb")
+require_relative "../../spec_helper.rb"
 
 describe Ohai::System, "plugin softlayer" do
   let(:plugin) { get_plugin("softlayer") }
