@@ -15,7 +15,7 @@
 # limitations under the License.
 #
 
-require File.expand_path(File.join(File.dirname(__FILE__), "..", "..", "/spec_helper.rb"))
+require_relative "../../spec_helper.rb"
 
 vbox_output = <<EOF
 Oracle VM VirtualBox Guest Additions Command Line Management Interface Version 5.0.2
