@@ -14,7 +14,8 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-require "spec_helper"
+
+require_relative "../../spec_helper.rb"
 
 describe Ohai::System, "plugin vmware" do
   let(:plugin) { get_plugin("vmware") }
