@@ -1,7 +1,7 @@
 #
 # Author:: Adam Jacob (<adam@chef.io>)
 # Author:: Claire McQuin (<claire@chef.io>)
-# Copyright:: Copyright (c) 2008-2016 Chef Software, Inc.
+# Copyright:: Copyright (c) 2008-2017, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -17,13 +17,14 @@
 # limitations under the License.
 #
 
-require File.expand_path(File.dirname(__FILE__) + "/../spec_helper.rb")
+require_relative "../spec_helper.rb"
 require "ohai/mixin/os"
 
 describe "Ohai::System" do
   extend IntegrationSupport
 
-  let(:ohai) { Ohai::System.new }
+  let(:ohai_external) {}
+  let(:ohai) { Ohai::System.new({ invoked_from_cli: true }) }
 
   describe "#initialize" do
     it "returns an Ohai::System object" do
@@ -38,23 +39,12 @@ describe "Ohai::System" do
       expect(ohai.v6_dependency_solver).to be_a_kind_of(Hash)
     end
 
-    it "merges deprecated config settings into the ohai config context" do
-      expect(Ohai::Log).to receive(:warn).
-        with(/Ohai::Config\[:disabled_plugins\] is deprecated/)
-      Ohai::Config[:disabled_plugins] = [ :Foo, :Baz ]
-      expect(Ohai::Config).to receive(:merge_deprecated_config).
-        and_call_original
-      Ohai::System.new
-      expect(Ohai.config[:disabled_plugins]).to eq([ :Foo, :Baz ])
-    end
-
     it "merges provided configuration options into the ohai config context" do
       config = {
         disabled_plugins: [ :Foo, :Baz ],
         directory: "/some/extra/plugins",
+        critical_plugins: [ :Foo, :Bar ],
       }
-      allow(Ohai::Config).to receive(:merge_deprecated_config)
-      expect(Ohai.config).to receive(:merge!).with(config).and_call_original
       Ohai::System.new(config)
       config.each do |option, value|
         expect(Ohai.config[option]).to eq(value)
@@ -66,58 +56,36 @@ describe "Ohai::System" do
 
       it "adds directory to plugin_path" do
         Ohai.config[:directory] = directory
-        Ohai::System.new
+        Ohai::System.new({ invoked_from_cli: true })
         expect(Ohai.config[:plugin_path]).to include(directory)
       end
     end
 
-    shared_examples_for "appendable deprecated configuration option" do
-      it "logs a warning and configures the option on the ohai config context" do
-        Ohai::Config[option] << value
-        expect(Ohai::Log).to receive(:warn).
-          with(/Ohai::Config\[:#{option}\] is deprecated/)
-        Ohai::System.new
-        expect(Ohai.config[option]).to include(value)
-      end
-    end
-
-    context "when a top-level hints_path is configured" do
-      include_examples "appendable deprecated configuration option" do
-        let(:option) { :hints_path }
-        let(:value) { "/path/to/hints" }
-      end
-    end
-
-    context "when a top-level plugin_path is configured" do
-      include_examples "appendable deprecated configuration option" do
-        let(:option) { :plugin_path }
-        let(:value) { "/path/to/plugins" }
-      end
-    end
-
-    context "first time configuration" do
-      before { allow(Ohai::Log).to receive(:configured?).and_return(false) }
-
+    context "when testing the intializer that does way too much" do
       it "configures logging" do
         log_level = :debug
         Ohai.config[:log_level] = log_level
-        expect(Ohai::Log).to receive(:init).with(Ohai.config[:log_location])
         expect(Ohai::Log).to receive(:level=).with(log_level)
-        Ohai::System.new
+        Ohai::System.new({ invoked_from_cli: true })
       end
 
       it "resolves log_level when set to :auto" do
         expect(Ohai::Log).to receive(:level=).with(:info)
-        Ohai::System.new
+        Ohai::System.new({ invoked_from_cli: true })
       end
-    end
 
-    context "after first time configuration" do
-      before { allow(Ohai::Log).to receive(:configured?).and_return(true) }
+      context "when called externally" do
+        it "does not configure logging" do
+          log_level = :debug
+          Ohai.config[:log_level] = log_level
+          expect(Ohai::Log).not_to receive(:level=).with(log_level)
+          Ohai::System.new
+        end
 
-      it "configures logging" do
-        expect(Ohai::Log).not_to receive(:init).with(Ohai.config[:log_location])
-        Ohai::System.new
+        it "does not resolve log_level when set to :auto" do
+          expect(Ohai::Log).not_to receive(:level=).with(:info)
+          Ohai::System.new
+        end
       end
     end
   end
@@ -199,6 +167,8 @@ EOF
         ohai.all_plugins
         expect(ohai.data[:zoo]).to eq("animals")
         expect(ohai.data[:park]).to eq("plants")
+        expect(ohai.data[:zoo]).to be_frozen
+        expect(ohai.data[:park]).to be_frozen
       end
 
       describe "when using :disabled_plugins" do
@@ -338,6 +308,15 @@ Ohai.plugin(:Park) do
     park("plants")
   end
 end
+EOF
+
+      with_plugin("fails.rb", <<EOF)
+Ohai.plugin(:Fails) do
+  provides 'fails'
+  collect_data(:default) do
+    fail 'thing'
+  end
+end
 EOF
 
       it "should collect data from all the plugins" do
@@ -345,6 +324,8 @@ EOF
         ohai.all_plugins
         expect(ohai.data[:zoo]).to eq("animals")
         expect(ohai.data[:park]).to eq("plants")
+        expect(ohai.data[:zoo]).to be_frozen
+        expect(ohai.data[:park]).to be_frozen
       end
 
       it "should write an error to Ohai::Log" do
@@ -372,6 +353,22 @@ EOF
           expect(ohai.data[:park]).to eq("plants")
         end
       end
+
+      describe "when using :critical_plugins" do
+        before do
+          Ohai.config[:critical_plugins] = [ :Fails ]
+        end
+        after do
+          Ohai.config[:critical_plugins] = []
+        end
+
+        it "should fail when critical plugins fail" do
+          Ohai.config[:plugin_path] = [ path_to(".") ]
+          expect(Ohai::Log).to receive(:error).with(/marked as critical/)
+          ohai.all_plugins
+        end
+
+      end
     end
 
     when_plugins_directory "contains v6 & v7 plugins in different directories" do
@@ -740,4 +737,49 @@ EOF
     end
   end
 
+  describe "when loading a specific plugin path" do
+    when_plugins_directory "contains v7 plugins" do
+      with_plugin("my_cookbook/canteloupe.rb", <<-E)
+        Ohai.plugin(:Canteloupe) do
+          provides 'canteloupe'
+
+          collect_data do
+            canteloupe Mash.new
+          end
+        end
+      E
+
+      with_plugin("english/english.rb", <<-E)
+        Ohai.plugin(:English) do
+          provides 'canteloupe/english'
+
+          depends 'canteloupe'
+
+          collect_data do
+            canteloupe[:english] = Mash.new
+            canteloupe[:english][:version] = 2014
+          end
+        end
+      E
+
+      with_plugin("french/french.rb", <<-E)
+        Ohai.plugin(:French) do
+          provides 'canteloupe/french'
+
+          depends 'canteloupe'
+
+          collect_data do
+            canteloupe[:french] = Mash.new
+            canteloupe[:french][:version] = 2012
+          end
+        end
+      E
+
+      it "should run all the plugins" do
+        ohai.run_additional_plugins(@plugins_directory)
+        expect(ohai.data[:canteloupe][:english][:version]).to eq(2014)
+        expect(ohai.data[:canteloupe][:french][:version]).to eq(2012)
+      end
+    end
+  end
 end
