@@ -16,7 +16,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-require "spec_helper"
+require_relative "../../spec_helper.rb"
 require "ohai/util/file_helper"
 
 class FileHelperMock
